@@ -5,8 +5,9 @@ from typing import Any, Dict, Optional
 
 import click
 
-from .click_common import command, format_output, EnumType
-from .device import Device, DeviceException
+from .click_common import EnumType, command, format_output
+from .device import Device
+from .exceptions import DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
