@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 import logging
 import sys
 
@@ -6,6 +5,7 @@ import click
 
 import miio  # noqa: E402
 from miio.click_common import ExceptionHandlerGroup, validate_ip, validate_token
+from miio.miioprotocol import MiIOProtocol
 
 _LOGGER = logging.getLogger(__name__)
 pass_dev = click.make_pass_decorator(miio.PhilipsEyecare)
@@ -66,7 +66,7 @@ def cli(ctx, ip: str, token: str, debug: int):
 @cli.command()
 def discover():
     """Search for plugs in the network."""
-    miio.PhilipsEyecare.discover()
+    MiIOProtocol.discover()
 
 
 @cli.command()
@@ -104,6 +104,20 @@ def off(dev: miio.PhilipsEyecare):
     click.echo("Power off: %s" % dev.off())
 
 
+@cli.command()
+@pass_dev
+def eyecare_on(dev: miio.PhilipsEyecare):
+    """Turn eyecare on."""
+    click.echo("Eyecare on: %s" % dev.eyecare_on())
+
+
+@cli.command()
+@pass_dev
+def eyecare_off(dev: miio.PhilipsEyecare):
+    """Turn eyecare off."""
+    click.echo("Eyecare off: %s" % dev.eyecare_off())
+
+
 @cli.command()
 @click.argument("level", callback=validate_brightness, required=True)
 @pass_dev
