@@ -1,37 +1,38 @@
 import enum
 import logging
 from collections import defaultdict
-from typing import Dict, Any, Optional
+from typing import Any, Dict, Optional
 
 import click
 
-from .click_common import command, format_output, EnumType
-from .device import Device, DeviceException
+from .click_common import EnumType, command, format_output
+from .device import Device
+from .exceptions import DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
-MODEL_POWER_STRIP_V1 = 'qmi.powerstrip.v1'
-MODEL_POWER_STRIP_V2 = 'zimi.powerstrip.v2'
+MODEL_POWER_STRIP_V1 = "qmi.powerstrip.v1"
+MODEL_POWER_STRIP_V2 = "zimi.powerstrip.v2"
 
 AVAILABLE_PROPERTIES = {
     MODEL_POWER_STRIP_V1: [
-        'power',
-        'temperature',
-        'current',
-        'mode',
-        'power_consume_rate',
-        'voltage',
-        'power_factor',
-        'elec_leakage',
+        "power",
+        "temperature",
+        "current",
+        "mode",
+        "power_consume_rate",
+        "voltage",
+        "power_factor",
+        "elec_leakage",
     ],
     MODEL_POWER_STRIP_V2: [
-        'power',
-        'temperature',
-        'current',
-        'mode',
-        'power_consume_rate',
-        'wifi_led',
-        'power_price',
+        "power",
+        "temperature",
+        "current",
+        "mode",
+        "power_consume_rate",
+        "wifi_led",
+        "power_price",
     ],
 }
 
@@ -41,8 +42,8 @@ class PowerStripException(DeviceException):
 
 
 class PowerMode(enum.Enum):
-    Eco = 'green'
-    Normal = 'normal'
+    Eco = "green"
+    Normal = "normal"
 
 
 class PowerStripStatus:
@@ -130,26 +131,30 @@ class PowerStripStatus:
         return None
 
     def __repr__(self) -> str:
-        s = "<PowerStripStatus power=%s, " \
-            "temperature=%s, " \
-            "voltage=%s, " \
-            "current=%s, " \
-            "load_power=%s, " \
-            "power_factor=%s " \
-            "power_price=%s, " \
-            "leakage_current=%s, " \
-            "mode=%s, " \
-            "wifi_led=%s>" % \
-            (self.power,
-             self.temperature,
-             self.voltage,
-             self.current,
-             self.load_power,
-             self.power_factor,
-             self.power_price,
-             self.leakage_current,
-             self.mode,
-             self.wifi_led)
+        s = (
+            "<PowerStripStatus power=%s, "
+            "temperature=%s, "
+            "voltage=%s, "
+            "current=%s, "
+            "load_power=%s, "
+            "power_factor=%s "
+            "power_price=%s, "
+            "leakage_current=%s, "
+            "mode=%s, "
+            "wifi_led=%s>"
+            % (
+                self.power,
+                self.temperature,
+                self.voltage,
+                self.current,
+                self.load_power,
+                self.power_factor,
+                self.power_price,
+                self.leakage_current,
+                self.mode,
+                self.wifi_led,
+            )
+        )
         return s
 
     def __json__(self):
@@ -159,9 +164,15 @@ class PowerStripStatus:
 class PowerStrip(Device):
     """Main class representing the smart power strip."""
 
-    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
-                 debug: int = 0, lazy_discover: bool = True,
-                 model: str = MODEL_POWER_STRIP_V1) -> None:
+    def __init__(
+        self,
+        ip: str = None,
+        token: str = None,
+        start_id: int = 0,
+        debug: int = 0,
+        lazy_discover: bool = True,
+        model: str = MODEL_POWER_STRIP_V1,
+    ) -> None:
         super().__init__(ip, token, start_id, debug, lazy_discover)
 
         if model in AVAILABLE_PROPERTIES:
@@ -181,15 +192,13 @@ class PowerStrip(Device):
             "Power price: {result.power_price}\n"
             "Leakage current: {result.leakage_current} A\n"
             "Mode: {result.mode}\n"
-            "WiFi LED: {result.wifi_led}\n")
+            "WiFi LED: {result.wifi_led}\n",
+        )
     )
     def status(self) -> PowerStripStatus:
         """Retrieve properties."""
         properties = AVAILABLE_PROPERTIES[self.model]
-        values = self.send(
-            "get_prop",
-            properties
-        )
+        values = self.send("get_prop", properties)
 
         properties_count = len(properties)
         values_count = len(values)
@@ -197,29 +206,25 @@ class PowerStrip(Device):
             _LOGGER.debug(
                 "Count (%s) of requested properties does not match the "
                 "count (%s) of received values.",
-                properties_count, values_count)
+                properties_count,
+                values_count,
+            )
 
-        return PowerStripStatus(
-            defaultdict(lambda: None, zip(properties, values)))
+        return PowerStripStatus(defaultdict(lambda: None, zip(properties, values)))
 
-    @command(
-        default_output=format_output("Powering on"),
-    )
+    @command(default_output=format_output("Powering on"))
     def on(self):
         """Power on."""
         return self.send("set_power", ["on"])
 
-    @command(
-        default_output=format_output("Powering off"),
-    )
+    @command(default_output=format_output("Powering off"))
     def off(self):
         """Power off."""
         return self.send("set_power", ["off"])
 
     @command(
         click.argument("mode", type=EnumType(PowerMode, False)),
-        default_output=format_output(
-            "Setting mode to {mode}")
+        default_output=format_output("Setting mode to {mode}"),
     )
     def set_power_mode(self, mode: PowerMode):
         """Set the power mode."""
@@ -230,9 +235,8 @@ class PowerStrip(Device):
     @command(
         click.argument("led", type=bool),
         default_output=format_output(
-            lambda led: "Turning on WiFi LED"
-            if led else "Turning off WiFi LED"
-        )
+            lambda led: "Turning on WiFi LED" if led else "Turning off WiFi LED"
+        ),
     )
     def set_wifi_led(self, led: bool):
         """Set the wifi led on/off."""
@@ -243,7 +247,7 @@ class PowerStrip(Device):
 
     @command(
         click.argument("price", type=int),
-        default_output=format_output("Setting power price to {price}")
+        default_output=format_output("Setting power price to {price}"),
     )
     def set_power_price(self, price: int):
         """Set the power price."""
@@ -256,8 +260,9 @@ class PowerStrip(Device):
         click.argument("power", type=bool),
         default_output=format_output(
             lambda led: "Turning on real-time power measurement"
-            if led else "Turning off real-time power measurement"
-        )
+            if led
+            else "Turning off real-time power measurement"
+        ),
     )
     def set_realtime_power(self, power: bool):
         """Set the realtime power on/off."""
