@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 import ast
 import json
 import logging
@@ -16,12 +15,13 @@ from tqdm import tqdm
 import miio  # noqa: E402
 from miio.click_common import (
     ExceptionHandlerGroup,
+    LiteralParamType,
     validate_ip,
     validate_token,
-    LiteralParamType,
 )
-from .device import UpdateState
-from .updater import OneShotServer
+from miio.device import UpdateState
+from miio.miioprotocol import MiIOProtocol
+from miio.updater import OneShotServer
 
 _LOGGER = logging.getLogger(__name__)
 pass_dev = click.make_pass_decorator(miio.Device, ensure=True)
@@ -100,7 +100,7 @@ def cleanup(vac: miio.Vacuum, *args, **kwargs):
 def discover(handshake):
     """Search for robots in the network."""
     if handshake:
-        miio.Vacuum.discover()
+        MiIOProtocol.discover()
     else:
         miio.Discovery.discover_mdns()
 
@@ -618,7 +618,7 @@ def update_firmware(vac: miio.Vacuum, url: str, md5: str, ip: str):
             try:
                 state = vac.update_state()
                 progress = vac.update_progress()
-            except:  # we may not get our messages through during upload
+            except:  # we may not get our messages through during upload # noqa
                 continue
 
             if state == UpdateState.Installing:
